@@ -21,11 +21,11 @@ DBIx::NinjaORM - Flexible Perl ORM for easy transitions from inline SQL to objec
 
 =head1 VERSION
 
-Version 2.1.2
+Version 2.1.3
 
 =cut
 
-our $VERSION = '2.1.2';
+our $VERSION = '2.1.3';
 
 
 =head1 DESCRIPTION
@@ -779,10 +779,12 @@ sub retrieve_list_nocache ## no critic (Subroutines::ProhibitExcessComplexity)
 				q|
 					SELECT COUNT(*)
 					FROM %s
-					$joins
-					$where
+					%s
+					%s
 				|,
 				$quoted_table_name,
+				$joins,
+				$where,
 			),
 			{},
 			map { @$_ } @$where_values,
